@@ -227,13 +227,17 @@ class GitHubSource(NvdSource):
                     severity
                 )
                 exploitabilityScore = score
-                description = fix_text(cve["summary"])
+                description = """# {}
+{}
+            """.format(
+                    cve.get("summary"), cve.get("description")
+                )
                 tdata = config.CVE_TPL % dict(
                     cve_id=cve_id,
                     cwe_id="UNKNOWN",
                     assigner=assigner,
                     references=ujson.dumps(references),
-                    description=description,
+                    description="",
                     vectorString=vectorString,
                     vendor=vendor.lower(),
                     product=product.lower(),
@@ -258,6 +262,6 @@ class GitHubSource(NvdSource):
                     vuln = NvdSource.convert_vuln(tdata_json)
                     vuln.description = description
                     ret_data.append(vuln)
-                except ujson.ValueError:
+                except Exception:
                     LOG.warning(tdata)
         return ret_data, page_info
